function polarDBS(phi, g, R, width, plane)

sty = ':';                                            

gdb = g .* (g > eps) + eps * (g <= eps);              
gdb = 10 * log10(gdb);
Rm = abs((10*ceil(max(gdb)/10))-R); 

gdb = gdb .* (gdb > -Rm) + (-Rm) * (gdb <= -Rm);      
gdb = (gdb + Rm)/Rm;                                  

M = 10*ceil(((max(gdb)-1)*Rm)/10);
gscale = (M+Rm)/Rm;
gdb = gdb/gscale;

x = gdb .* cos(phi);
y = gdb .* sin(phi);

N0 = 400;
phi0 = (0:N0) * 2*pi / N0;  
x0 = sin(phi0);                                       
y0 = cos(phi0);        

plot(x, y, 'LineWidth', width);

hold on;
plot(x0, y0, 0.75*x0, 0.75*y0, sty, 0.50*x0, 0.50*y0, sty, 0.25*x0, 0.25*y0, sty);

axis square;
R = 1.1; 
axis([-R, R, -R, R]);
axis off;

Nf = 10;                 

line([0,0],[-1,1]);
line([-1,1],[0,0]);

text(0, 1.02,  ' 90^o',   'fontsize', Nf, 'horiz', 'center', 'vert', 'bottom');
text(0, -0.99, '-90^o', 'fontsize', Nf, 'horiz', 'center', 'vert', 'top');

text(1, -0.05,  ' 0^o', 'fontsize', Nf, 'horiz', 'left', 'vert', 'middle');
text(-1.02, 0.01, '180^o',  'fontsize', Nf, 'horiz', 'right', 'vert', 'middle');

x1 = cos(pi/3); y1 = sin(pi/3);
x2 = cos(pi/6); y2 = sin(pi/6);
line([-x1,x1], [-y1,y1], 'linestyle', sty);
line([-x2,x2], [-y2,y2], 'linestyle', sty);
line([-x2,x2], [y2,-y2], 'linestyle', sty);
line([-x1,x1], [y1,-y1], 'linestyle', sty);
  
text(1.02*x1,1.02*y1,         '60^o',  'fontsize', Nf, 'horiz', 'left', 'vert', 'bottom');
text(0.95*x1,-0.97*y1,        '-60^o', 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');
text(1.04*x2,0.97*y2, '30^o', 'fontsize', Nf, 'horiz', 'left', 'vert', 'bottom');
text(0.98*x2,-0.93*y2,        '-30^o', 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');
  
text(-0.91*x1,1.02*y1,  '120^o',  'fontsize', Nf, 'horiz', 'right', 'vert', 'bottom');
text(-0.97*x1,-1.01*y1, '-120^o', 'fontsize', Nf, 'horiz', 'right', 'vert', 'top');
text(-1.02*x2,0.97*y2,  '150^o',  'fontsize', Nf, 'horiz', 'right', 'vert', 'bottom');
text(-1.01*x2,-1.01*y2, '-150^o', 'fontsize', Nf, 'horiz', 'right', 'vert', 'top');

s1 = sprintf('%.1f', M-0.25*(Rm+M));
s2 = sprintf('%.1f', M-0.50*(Rm+M));
s3 = sprintf('%.1f', M-0.75*(Rm+M));
s4 = sprintf('%.1f', M);

text(0.7, 0.125, s1, 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');
text(0.45, 0.125, s2, 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');
text(0.2, 0.125, s3, 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');
text(0.95, 0.125, s4, 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');

text(0.55, -0.005, 'dBi', 'fontsize', Nf, 'horiz', 'left', 'vert', 'top');

if (length(plane) == 2)
    switch plane
        case 'XY'
            text(1.07*cos(pi/12), 1.07*sin(pi/12),  '\phi', 'fontsize', Nf+2, 'horiz', 'left');
            title('Rovina XY (\theta = \pi/2)','fontsize', Nf);
        case 'XZ'
            text(1.07*cos(pi/12), 1.07*sin(pi/12),  '\theta', 'fontsize', Nf+2, 'horiz', 'left');
            title('Rovina XZ (\phi = 0)','fontsize', Nf);
        case 'YZ'
            text(1.07*cos(pi/12), 1.07*sin(pi/12),  '\theta', 'fontsize', Nf+2, 'horiz', 'left');
            title('Rovina YZ (\phi = \pi/2)','fontsize', Nf);
    end
end
hold off            

